==> joystick_1.4.9.orig.tar.bz2: linuxconsoletools-1.4.9/utils/serio-ids.h <==
#ifndef _SERIO_IDS_H
#define _SERIO_IDS_H

#ifndef SERIO_RS232
# define SERIO_RS232	0x02
#endif

/*
 * Serio types
 */
#ifndef SERIO_UNKNOWN
# define SERIO_UNKNOWN		0x00
#endif
#ifndef SERIO_MSC
# define SERIO_MSC		0x01
#endif
#ifndef SERIO_SUN
# define SERIO_SUN		0x02
#endif
#ifndef SERIO_MS
# define SERIO_MS		0x03
#endif
#ifndef SERIO_MP
# define SERIO_MP		0x04
#endif
#ifndef SERIO_MZ
# define SERIO_MZ		0x05
#endif
#ifndef SERIO_MZP
# define SERIO_MZP		0x06
#endif
#ifndef SERIO_MZPP
# define SERIO_MZPP		0x07
#endif
#ifndef SERIO_VSXXXAA
# define SERIO_VSXXXAA		0x08
#endif
#ifndef SERIO_SUNKBD
# define SERIO_SUNKBD		0x10
#endif
#ifndef SERIO_WARRIOR
# define SERIO_WARRIOR		0x18
#endif
#ifndef SERIO_SPACEORB
# define SERIO_SPACEORB		0x19
#endif
#ifndef SERIO_MAGELLAN
# define SERIO_MAGELLAN		0x1a
#endif
#ifndef SERIO_SPACEBALL
# define SERIO_SPACEBALL	0x1b
#endif
#ifndef SERIO_GUNZE
# define SERIO_GUNZE		0x1c
#endif
#ifndef SERIO_IFORCE
# define SERIO_IFORCE		0x1d
#endif
#ifndef SERIO_STINGER
# define SERIO_STINGER		0x1e
#endif
#ifndef SERIO_NEWTON
# define SERIO_NEWTON		0x1f
#endif
#ifndef SERIO_STOWAWAY
# define SERIO_STOWAWAY		0x20
#endif
#ifndef SERIO_H3600
# define SERIO_H3600		0x21
#endif
#ifndef SERIO_PS2SER
# define SERIO_PS2SER		0x22
#endif
#ifndef SERIO_TWIDKBD
# define SERIO_TWIDKBD		0x23
#endif
#ifndef SERIO_TWIDJOY
# define SERIO_TWIDJOY		0x24
#endif
#ifndef SERIO_HIL
# define SERIO_HIL		0x25
#endif
#ifndef SERIO_SNES232
# define SERIO_SNES232		0x26
#endif
#ifndef SERIO_SEMTECH
# define SERIO_SEMTECH		0x27
#endif
#ifndef SERIO_LKKBD
# define SERIO_LKKBD		0x28
#endif
#ifndef SERIO_ELO
# define SERIO_ELO		0x29
#endif
#ifndef SERIO_MICROTOUCH
# define SERIO_MICROTOUCH	0x30
#endif
#ifndef SERIO_PENMOUNT
# define SERIO_PENMOUNT		0x31
#endif
#ifndef SERIO_TOUCHRIGHT
# define SERIO_TOUCHRIGHT	0x32
#endif
#ifndef SERIO_TOUCHWIN
# define SERIO_TOUCHWIN		0x33
#endif
#ifndef SERIO_TAOSEVM
# define SERIO_TAOSEVM		0x34
#endif
#ifndef SERIO_FUJITSU
# define SERIO_FUJITSU		0x35
#endif
#ifndef SERIO_ZHENHUA
# define SERIO_ZHENHUA		0x36
#endif
#ifndef SERIO_INEXIO
# define SERIO_INEXIO		0x37
#endif
#ifndef SERIO_TOUCHIT213
# define SERIO_TOUCHIT213	0x38
#endif
#ifndef SERIO_W8001
# define SERIO_W8001		0x39
#endif
#ifndef SERIO_PSMULT
# define SERIO_PS2MULT		0x3c
#endif
#ifndef SERIO_WACOM_IV
# define SERIO_WACOM_IV		0x3e
#endif
#ifndef SERIO_EASYPEN
# define SERIO_EASYPEN		0x3f
#endif

#endif

==> joystick_1.6.1.orig.tar.bz2: linuxconsoletools-1.6.1/utils/serio-ids.h <==
#ifndef _SERIO_IDS_H
#define _SERIO_IDS_H

#ifndef SERIO_RS232
# define SERIO_RS232	0x02
#endif

/*
 * Serio types
 */
#ifndef SERIO_UNKNOWN
# define SERIO_UNKNOWN		0x00
#endif
#ifndef SERIO_MSC
# define SERIO_MSC		0x01
#endif
#ifndef SERIO_SUN
# define SERIO_SUN		0x02
#endif
#ifndef SERIO_MS
# define SERIO_MS		0x03
#endif
#ifndef SERIO_MP
# define SERIO_MP		0x04
#endif
#ifndef SERIO_MZ
# define SERIO_MZ		0x05
#endif
#ifndef SERIO_MZP
# define SERIO_MZP		0x06
#endif
#ifndef SERIO_MZPP
# define SERIO_MZPP		0x07
#endif
#ifndef SERIO_VSXXXAA
# define SERIO_VSXXXAA		0x08
#endif
#ifndef SERIO_SUNKBD
# define SERIO_SUNKBD		0x10
#endif
#ifndef SERIO_WARRIOR
# define SERIO_WARRIOR		0x18
#endif
#ifndef SERIO_SPACEORB
# define SERIO_SPACEORB		0x19
#endif
#ifndef SERIO_MAGELLAN
# define SERIO_MAGELLAN		0x1a
#endif
#ifndef SERIO_SPACEBALL
# define SERIO_SPACEBALL	0x1b
#endif
#ifndef SERIO_GUNZE
# define SERIO_GUNZE		0x1c
#endif
#ifndef SERIO_IFORCE
# define SERIO_IFORCE		0x1d
#endif
#ifndef SERIO_STINGER
# define SERIO_STINGER		0x1e
#endif
#ifndef SERIO_NEWTON
# define SERIO_NEWTON		0x1f
#endif
#ifndef SERIO_STOWAWAY
# define SERIO_STOWAWAY		0x20
#endif
#ifndef SERIO_H3600
# define SERIO_H3600		0x21
#endif
#ifndef SERIO_PS2SER
# define SERIO_PS2SER		0x22
#endif
#ifndef SERIO_TWIDKBD
# define SERIO_TWIDKBD		0x23
#endif
#ifndef SERIO_TWIDJOY
# define SERIO_TWIDJOY		0x24
#endif
#ifndef SERIO_HIL
# define SERIO_HIL		0x25
#endif
#ifndef SERIO_SNES232
# define SERIO_SNES232		0x26
#endif
#ifndef SERIO_SEMTECH
# define SERIO_SEMTECH		0x27
#endif
#ifndef SERIO_LKKBD
# define SERIO_LKKBD		0x28
#endif
#ifndef SERIO_ELO
# define SERIO_ELO		0x29
#endif
#ifndef SERIO_MICROTOUCH
# define SERIO_MICROTOUCH	0x30
#endif
#ifndef SERIO_PENMOUNT
# define SERIO_PENMOUNT		0x31
#endif
#ifndef SERIO_TOUCHRIGHT
# define SERIO_TOUCHRIGHT	0x32
#endif
#ifndef SERIO_TOUCHWIN
# define SERIO_TOUCHWIN		0x33
#endif
#ifndef SERIO_TAOSEVM
# define SERIO_TAOSEVM		0x34
#endif
#ifndef SERIO_FUJITSU
# define SERIO_FUJITSU		0x35
#endif
#ifndef SERIO_ZHENHUA
# define SERIO_ZHENHUA		0x36
#endif
#ifndef SERIO_INEXIO
# define SERIO_INEXIO		0x37
#endif
#ifndef SERIO_TOUCHIT213
# define SERIO_TOUCHIT213	0x38
#endif
#ifndef SERIO_W8001
# define SERIO_W8001		0x39
#endif
#ifndef SERIO_PSMULT
# define SERIO_PS2MULT		0x3c
#endif
#ifndef SERIO_WACOM_IV
# define SERIO_WACOM_IV		0x3e
#endif
#ifndef SERIO_EASYPEN
# define SERIO_EASYPEN		0x3f
#endif
#ifndef SERIO_PULSE8_CEC
# define SERIO_PULSE8_CEC	0x40
#endif
#ifndef SERIO_RAINSHADOW_CEC
# define SERIO_RAINSHADOW_CEC	0x41
#endif

#endif
